bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.random
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.random